<?php

/**
 * VVIP functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package WordPress
 * @subpackage VVIP
 * @since 1.0
 */

/**
 * Theme Extra Functions
 */
require get_theme_file_path( '/inc/theme-functions.php' );

include get_template_directory().'/feed.class.php';

/**
 * Theme CSS JS
 */
require get_theme_file_path( '/inc/theme-css-js.php' );

/**
 * Kirki
 */
include_once get_theme_file_path( '/lib/kirki-develop/kirki.php' );
include_once get_theme_file_path( '/lib/theme-customizer.php' );

/**
 * Theme plugins
 */
include_once get_theme_file_path( '/lib/require_plugins.php' );
include_once get_theme_file_path( '/lib/import_demo.php' );

if ( ! isset( $content_width ) ) $content_width = 900;

 /**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function vvip_bootstraping() {
	/*
	 * Make theme available for translation.
	 */
	load_theme_textdomain( 'vvip', get_theme_file_path( '/lang' ) );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
    add_image_size( 'vvip-page-image', 1000, 400, array('center', 'center') );

	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'top'    => __( 'Top Menu', 'vvip' )
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );


	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
	) );

		/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
	) );

}
add_action( 'after_setup_theme', 'vvip_bootstraping' );

/**
 * Enqueue scripts and styles.
 */
function vvip_assets(){
    wp_enqueue_style( 'bootstrap-css', get_theme_file_uri('/assets/bootstrap/css/bootstrap.min.css') );
    wp_enqueue_style( 'grid-css', get_theme_file_uri('/assets/css/grid-style.css') );
    wp_enqueue_style( 'fontawesome-css', get_theme_file_uri('/assets/css/fontawesome-all.css') );
    wp_enqueue_style( 'headline-css', get_theme_file_uri('/assets/css/headline.css') );
    wp_enqueue_style( 'owl.carousel-css', get_theme_file_uri('/assets/vendor/css/owl.carousel.css') );
    wp_enqueue_style( 'magnific-css', get_theme_file_uri('/assets/css/magnific-popup.css') );
    wp_enqueue_style( 'owl.theme.default-css', get_theme_file_uri('/assets/vendor/css/owl.theme.default.css') );
    wp_enqueue_style( 'lineProgressbar-css', get_theme_file_uri('/assets/css/jquery.lineProgressbar.min.css') );
    wp_enqueue_style( 'style-css', get_theme_file_uri('/assets/css/style.css') );
    wp_enqueue_style( 'responsive-css', get_theme_file_uri('/assets/css/responsive.css') );
    wp_enqueue_style( 'main-css', get_stylesheet_uri() );

    wp_enqueue_script('bootstrap-js', get_theme_file_uri('/assets/bootstrap/js/bootstrap.min.js'), array('jquery'), time(), true);
    wp_enqueue_script('headline-js', get_theme_file_uri('/assets/js/headline.js'), array('jquery'), time(), true);
    wp_enqueue_script('waypoints-js', get_theme_file_uri('/assets/js/jquery.waypoints.min.js'), array('jquery'), time(), true);
    wp_enqueue_script('counterup-js', get_theme_file_uri('/assets/js/jquery.counterup.min.js'), array('jquery'), time(), true);
    wp_enqueue_script('magnific-js', get_theme_file_uri('/assets/js/jquery.magnific-popup.min.js'), array('jquery'), time(), true);
    wp_enqueue_script('mixitup-js', get_theme_file_uri('/assets/js/jquery.mixitup.js'), array('jquery'), time(), true);
    wp_enqueue_script('lineProgressbar-js', get_theme_file_uri('/assets/js/jquery.lineProgressbar.js'), array('jquery'), time(), false);
    wp_enqueue_script('owl.carousel-js', get_theme_file_uri('/assets/vendor/js/owl.carousel.min.js'), array('jquery'), time(), true);
    wp_enqueue_script('particle-js', get_theme_file_uri('/assets/js/particles.js'), array('jquery'), time(), true);
    wp_enqueue_script('particle-main-js', get_theme_file_uri('/assets/js/particle-main.js'), array('jquery'), time(), true);
    wp_enqueue_script('vid-js', get_theme_file_uri('/assets/js/jquery.vide.js'), array('jquery'), time(), true);
    if( is_singular() ){
        wp_enqueue_script( "comment-reply" );
    }
    wp_enqueue_script('main-js', get_theme_file_uri('/assets/js/main.js'), array('jquery'), time(), true);
}
add_action( 'wp_enqueue_scripts', 'vvip_assets' );

/**
 * Sidebar
 */
function vvip_sidebar(){

	register_sidebar(
		array(
			'name'          => __( 'Sidebar', 'vvip' ),
			'id'            => 'vvip-sidebar-one',
			'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'vvip' ),
			'before_widget' => '<div id="%1$s" class="widget vvip-sidebar-widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);

}
add_action( 'widgets_init', 'vvip_sidebar' );

/**
 * Fall Back Menu
 */
function vvip_fallback_menu(){
    ?>
    <ul class="nav navbar-nav navbar-right">
        <li><a class="smoth-scroll" href="#home">Home</a>
        </li>
        <li><a class="smoth-scroll" href="#about">About</a>
        </li>
        <li><a class="smoth-scroll" href="#service">Service</a>
        </li>
        <li><a class="smoth-scroll" href="#work">Works</a>
        </li>
        <li><a class="smoth-scroll" href="#blog">Blog</a>
        </li>
        <li><a class="smoth-scroll" href="#contact">Contact Me</a>
        </li>
    </ul>
    <?php
}

/**
 * Add Class In a Tag In Menu
 */
function vvip_add_menuclass($aclass) {
return preg_replace('/<a/', '<a class="smoth-scroll"', $aclass, -1);
}
add_filter('wp_nav_menu','vvip_add_menuclass');


/**
 * Move Comment
 */
function vvip_move_comment_field_to_bottom( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
}
    
add_filter( 'comment_form_fields', 'vvip_move_comment_field_to_bottom' );
